@@ -1,7 +1,6 @@
 import datetime
 import json
 from dataclasses import asdict
-from typing import Type
 
 from fractal.core.event_sourcing.event import SendingEvent
 from fractal.core.event_sourcing.event_projector import EventProjector
@@ -10,7 +9,7 @@ from fractal.core.utils.json_encoder import EnhancedEncoder
 
 
 class PrintEventProjector(EventProjector):
-    def project(self, id: str, event: Type[SendingEvent]):
+    def project(self, id: str, event: SendingEvent):
         message = Message(
             id=id,
             occurred_on=datetime.datetime.now(tz=datetime.timezone.utc),
